"""
Type annotations for eks service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/)

Copyright 2026 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_eks.client import EKSClient

    session = Session()
    client: EKSClient = session.client("eks")
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    DescribeAddonVersionsPaginator,
    DescribeClusterVersionsPaginator,
    ListAccessEntriesPaginator,
    ListAccessPoliciesPaginator,
    ListAddonsPaginator,
    ListAssociatedAccessPoliciesPaginator,
    ListCapabilitiesPaginator,
    ListClustersPaginator,
    ListEksAnywhereSubscriptionsPaginator,
    ListFargateProfilesPaginator,
    ListIdentityProviderConfigsPaginator,
    ListInsightsPaginator,
    ListNodegroupsPaginator,
    ListPodIdentityAssociationsPaginator,
    ListUpdatesPaginator,
)
from .type_defs import (
    AssociateAccessPolicyRequestTypeDef,
    AssociateAccessPolicyResponseTypeDef,
    AssociateEncryptionConfigRequestTypeDef,
    AssociateEncryptionConfigResponseTypeDef,
    AssociateIdentityProviderConfigRequestTypeDef,
    AssociateIdentityProviderConfigResponseTypeDef,
    CreateAccessEntryRequestTypeDef,
    CreateAccessEntryResponseTypeDef,
    CreateAddonRequestTypeDef,
    CreateAddonResponseTypeDef,
    CreateCapabilityRequestTypeDef,
    CreateCapabilityResponseTypeDef,
    CreateClusterRequestTypeDef,
    CreateClusterResponseTypeDef,
    CreateEksAnywhereSubscriptionRequestTypeDef,
    CreateEksAnywhereSubscriptionResponseTypeDef,
    CreateFargateProfileRequestTypeDef,
    CreateFargateProfileResponseTypeDef,
    CreateNodegroupRequestTypeDef,
    CreateNodegroupResponseTypeDef,
    CreatePodIdentityAssociationRequestTypeDef,
    CreatePodIdentityAssociationResponseTypeDef,
    DeleteAccessEntryRequestTypeDef,
    DeleteAddonRequestTypeDef,
    DeleteAddonResponseTypeDef,
    DeleteCapabilityRequestTypeDef,
    DeleteCapabilityResponseTypeDef,
    DeleteClusterRequestTypeDef,
    DeleteClusterResponseTypeDef,
    DeleteEksAnywhereSubscriptionRequestTypeDef,
    DeleteEksAnywhereSubscriptionResponseTypeDef,
    DeleteFargateProfileRequestTypeDef,
    DeleteFargateProfileResponseTypeDef,
    DeleteNodegroupRequestTypeDef,
    DeleteNodegroupResponseTypeDef,
    DeletePodIdentityAssociationRequestTypeDef,
    DeletePodIdentityAssociationResponseTypeDef,
    DeregisterClusterRequestTypeDef,
    DeregisterClusterResponseTypeDef,
    DescribeAccessEntryRequestTypeDef,
    DescribeAccessEntryResponseTypeDef,
    DescribeAddonConfigurationRequestTypeDef,
    DescribeAddonConfigurationResponseTypeDef,
    DescribeAddonRequestTypeDef,
    DescribeAddonResponseTypeDef,
    DescribeAddonVersionsRequestTypeDef,
    DescribeAddonVersionsResponseTypeDef,
    DescribeCapabilityRequestTypeDef,
    DescribeCapabilityResponseTypeDef,
    DescribeClusterRequestTypeDef,
    DescribeClusterResponseTypeDef,
    DescribeClusterVersionsRequestTypeDef,
    DescribeClusterVersionsResponseTypeDef,
    DescribeEksAnywhereSubscriptionRequestTypeDef,
    DescribeEksAnywhereSubscriptionResponseTypeDef,
    DescribeFargateProfileRequestTypeDef,
    DescribeFargateProfileResponseTypeDef,
    DescribeIdentityProviderConfigRequestTypeDef,
    DescribeIdentityProviderConfigResponseTypeDef,
    DescribeInsightRequestTypeDef,
    DescribeInsightResponseTypeDef,
    DescribeInsightsRefreshRequestTypeDef,
    DescribeInsightsRefreshResponseTypeDef,
    DescribeNodegroupRequestTypeDef,
    DescribeNodegroupResponseTypeDef,
    DescribePodIdentityAssociationRequestTypeDef,
    DescribePodIdentityAssociationResponseTypeDef,
    DescribeUpdateRequestTypeDef,
    DescribeUpdateResponseTypeDef,
    DisassociateAccessPolicyRequestTypeDef,
    DisassociateIdentityProviderConfigRequestTypeDef,
    DisassociateIdentityProviderConfigResponseTypeDef,
    ListAccessEntriesRequestTypeDef,
    ListAccessEntriesResponseTypeDef,
    ListAccessPoliciesRequestTypeDef,
    ListAccessPoliciesResponseTypeDef,
    ListAddonsRequestTypeDef,
    ListAddonsResponseTypeDef,
    ListAssociatedAccessPoliciesRequestTypeDef,
    ListAssociatedAccessPoliciesResponseTypeDef,
    ListCapabilitiesRequestTypeDef,
    ListCapabilitiesResponseTypeDef,
    ListClustersRequestTypeDef,
    ListClustersResponseTypeDef,
    ListEksAnywhereSubscriptionsRequestTypeDef,
    ListEksAnywhereSubscriptionsResponseTypeDef,
    ListFargateProfilesRequestTypeDef,
    ListFargateProfilesResponseTypeDef,
    ListIdentityProviderConfigsRequestTypeDef,
    ListIdentityProviderConfigsResponseTypeDef,
    ListInsightsRequestTypeDef,
    ListInsightsResponseTypeDef,
    ListNodegroupsRequestTypeDef,
    ListNodegroupsResponseTypeDef,
    ListPodIdentityAssociationsRequestTypeDef,
    ListPodIdentityAssociationsResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListUpdatesRequestTypeDef,
    ListUpdatesResponseTypeDef,
    RegisterClusterRequestTypeDef,
    RegisterClusterResponseTypeDef,
    StartInsightsRefreshRequestTypeDef,
    StartInsightsRefreshResponseTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateAccessEntryRequestTypeDef,
    UpdateAccessEntryResponseTypeDef,
    UpdateAddonRequestTypeDef,
    UpdateAddonResponseTypeDef,
    UpdateCapabilityRequestTypeDef,
    UpdateCapabilityResponseTypeDef,
    UpdateClusterConfigRequestTypeDef,
    UpdateClusterConfigResponseTypeDef,
    UpdateClusterVersionRequestTypeDef,
    UpdateClusterVersionResponseTypeDef,
    UpdateEksAnywhereSubscriptionRequestTypeDef,
    UpdateEksAnywhereSubscriptionResponseTypeDef,
    UpdateNodegroupConfigRequestTypeDef,
    UpdateNodegroupConfigResponseTypeDef,
    UpdateNodegroupVersionRequestTypeDef,
    UpdateNodegroupVersionResponseTypeDef,
    UpdatePodIdentityAssociationRequestTypeDef,
    UpdatePodIdentityAssociationResponseTypeDef,
)
from .waiter import (
    AddonActiveWaiter,
    AddonDeletedWaiter,
    ClusterActiveWaiter,
    ClusterDeletedWaiter,
    FargateProfileActiveWaiter,
    FargateProfileDeletedWaiter,
    NodegroupActiveWaiter,
    NodegroupDeletedWaiter,
)

if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack

__all__ = ("EKSClient",)

class Exceptions(BaseClientExceptions):
    AccessDeniedException: type[BotocoreClientError]
    BadRequestException: type[BotocoreClientError]
    ClientError: type[BotocoreClientError]
    ClientException: type[BotocoreClientError]
    InvalidParameterException: type[BotocoreClientError]
    InvalidRequestException: type[BotocoreClientError]
    InvalidStateException: type[BotocoreClientError]
    NotFoundException: type[BotocoreClientError]
    ResourceInUseException: type[BotocoreClientError]
    ResourceLimitExceededException: type[BotocoreClientError]
    ResourceNotFoundException: type[BotocoreClientError]
    ResourcePropagationDelayException: type[BotocoreClientError]
    ServerException: type[BotocoreClientError]
    ServiceUnavailableException: type[BotocoreClientError]
    ThrottlingException: type[BotocoreClientError]
    UnsupportedAvailabilityZoneException: type[BotocoreClientError]

class EKSClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks.html#EKS.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        EKSClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks.html#EKS.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#generate_presigned_url)
        """

    def associate_access_policy(
        self, **kwargs: Unpack[AssociateAccessPolicyRequestTypeDef]
    ) -> AssociateAccessPolicyResponseTypeDef:
        """
        Associates an access policy and its scope to an access entry.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/associate_access_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#associate_access_policy)
        """

    def associate_encryption_config(
        self, **kwargs: Unpack[AssociateEncryptionConfigRequestTypeDef]
    ) -> AssociateEncryptionConfigResponseTypeDef:
        """
        Associates an encryption configuration to an existing cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/associate_encryption_config.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#associate_encryption_config)
        """

    def associate_identity_provider_config(
        self, **kwargs: Unpack[AssociateIdentityProviderConfigRequestTypeDef]
    ) -> AssociateIdentityProviderConfigResponseTypeDef:
        """
        Associates an identity provider configuration to a cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/associate_identity_provider_config.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#associate_identity_provider_config)
        """

    def create_access_entry(
        self, **kwargs: Unpack[CreateAccessEntryRequestTypeDef]
    ) -> CreateAccessEntryResponseTypeDef:
        """
        Creates an access entry.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_access_entry.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_access_entry)
        """

    def create_addon(
        self, **kwargs: Unpack[CreateAddonRequestTypeDef]
    ) -> CreateAddonResponseTypeDef:
        """
        Creates an Amazon EKS add-on.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_addon.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_addon)
        """

    def create_capability(
        self, **kwargs: Unpack[CreateCapabilityRequestTypeDef]
    ) -> CreateCapabilityResponseTypeDef:
        """
        Creates a managed capability resource for an Amazon EKS cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_capability.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_capability)
        """

    def create_cluster(
        self, **kwargs: Unpack[CreateClusterRequestTypeDef]
    ) -> CreateClusterResponseTypeDef:
        """
        Creates an Amazon EKS control plane.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_cluster.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_cluster)
        """

    def create_eks_anywhere_subscription(
        self, **kwargs: Unpack[CreateEksAnywhereSubscriptionRequestTypeDef]
    ) -> CreateEksAnywhereSubscriptionResponseTypeDef:
        """
        Creates an EKS Anywhere subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_eks_anywhere_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_eks_anywhere_subscription)
        """

    def create_fargate_profile(
        self, **kwargs: Unpack[CreateFargateProfileRequestTypeDef]
    ) -> CreateFargateProfileResponseTypeDef:
        """
        Creates an Fargate profile for your Amazon EKS cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_fargate_profile.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_fargate_profile)
        """

    def create_nodegroup(
        self, **kwargs: Unpack[CreateNodegroupRequestTypeDef]
    ) -> CreateNodegroupResponseTypeDef:
        """
        Creates a managed node group for an Amazon EKS cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_nodegroup.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_nodegroup)
        """

    def create_pod_identity_association(
        self, **kwargs: Unpack[CreatePodIdentityAssociationRequestTypeDef]
    ) -> CreatePodIdentityAssociationResponseTypeDef:
        """
        Creates an EKS Pod Identity association between a service account in an Amazon
        EKS cluster and an IAM role with <i>EKS Pod Identity</i>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/create_pod_identity_association.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#create_pod_identity_association)
        """

    def delete_access_entry(
        self, **kwargs: Unpack[DeleteAccessEntryRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Deletes an access entry.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_access_entry.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_access_entry)
        """

    def delete_addon(
        self, **kwargs: Unpack[DeleteAddonRequestTypeDef]
    ) -> DeleteAddonResponseTypeDef:
        """
        Deletes an Amazon EKS add-on.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_addon.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_addon)
        """

    def delete_capability(
        self, **kwargs: Unpack[DeleteCapabilityRequestTypeDef]
    ) -> DeleteCapabilityResponseTypeDef:
        """
        Deletes a managed capability from your Amazon EKS cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_capability.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_capability)
        """

    def delete_cluster(
        self, **kwargs: Unpack[DeleteClusterRequestTypeDef]
    ) -> DeleteClusterResponseTypeDef:
        """
        Deletes an Amazon EKS cluster control plane.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_cluster.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_cluster)
        """

    def delete_eks_anywhere_subscription(
        self, **kwargs: Unpack[DeleteEksAnywhereSubscriptionRequestTypeDef]
    ) -> DeleteEksAnywhereSubscriptionResponseTypeDef:
        """
        Deletes an expired or inactive subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_eks_anywhere_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_eks_anywhere_subscription)
        """

    def delete_fargate_profile(
        self, **kwargs: Unpack[DeleteFargateProfileRequestTypeDef]
    ) -> DeleteFargateProfileResponseTypeDef:
        """
        Deletes an Fargate profile.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_fargate_profile.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_fargate_profile)
        """

    def delete_nodegroup(
        self, **kwargs: Unpack[DeleteNodegroupRequestTypeDef]
    ) -> DeleteNodegroupResponseTypeDef:
        """
        Deletes a managed node group.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_nodegroup.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_nodegroup)
        """

    def delete_pod_identity_association(
        self, **kwargs: Unpack[DeletePodIdentityAssociationRequestTypeDef]
    ) -> DeletePodIdentityAssociationResponseTypeDef:
        """
        Deletes a EKS Pod Identity association.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/delete_pod_identity_association.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#delete_pod_identity_association)
        """

    def deregister_cluster(
        self, **kwargs: Unpack[DeregisterClusterRequestTypeDef]
    ) -> DeregisterClusterResponseTypeDef:
        """
        Deregisters a connected cluster to remove it from the Amazon EKS control plane.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/deregister_cluster.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#deregister_cluster)
        """

    def describe_access_entry(
        self, **kwargs: Unpack[DescribeAccessEntryRequestTypeDef]
    ) -> DescribeAccessEntryResponseTypeDef:
        """
        Describes an access entry.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_access_entry.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_access_entry)
        """

    def describe_addon(
        self, **kwargs: Unpack[DescribeAddonRequestTypeDef]
    ) -> DescribeAddonResponseTypeDef:
        """
        Describes an Amazon EKS add-on.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_addon.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_addon)
        """

    def describe_addon_configuration(
        self, **kwargs: Unpack[DescribeAddonConfigurationRequestTypeDef]
    ) -> DescribeAddonConfigurationResponseTypeDef:
        """
        Returns configuration options.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_addon_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_addon_configuration)
        """

    def describe_addon_versions(
        self, **kwargs: Unpack[DescribeAddonVersionsRequestTypeDef]
    ) -> DescribeAddonVersionsResponseTypeDef:
        """
        Describes the versions for an add-on.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_addon_versions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_addon_versions)
        """

    def describe_capability(
        self, **kwargs: Unpack[DescribeCapabilityRequestTypeDef]
    ) -> DescribeCapabilityResponseTypeDef:
        """
        Returns detailed information about a specific managed capability in your Amazon
        EKS cluster, including its current status, configuration, health information,
        and any issues that may be affecting its operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_capability.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_capability)
        """

    def describe_cluster(
        self, **kwargs: Unpack[DescribeClusterRequestTypeDef]
    ) -> DescribeClusterResponseTypeDef:
        """
        Describes an Amazon EKS cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_cluster.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_cluster)
        """

    def describe_cluster_versions(
        self, **kwargs: Unpack[DescribeClusterVersionsRequestTypeDef]
    ) -> DescribeClusterVersionsResponseTypeDef:
        """
        Lists available Kubernetes versions for Amazon EKS clusters.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_cluster_versions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_cluster_versions)
        """

    def describe_eks_anywhere_subscription(
        self, **kwargs: Unpack[DescribeEksAnywhereSubscriptionRequestTypeDef]
    ) -> DescribeEksAnywhereSubscriptionResponseTypeDef:
        """
        Returns descriptive information about a subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_eks_anywhere_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_eks_anywhere_subscription)
        """

    def describe_fargate_profile(
        self, **kwargs: Unpack[DescribeFargateProfileRequestTypeDef]
    ) -> DescribeFargateProfileResponseTypeDef:
        """
        Describes an Fargate profile.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_fargate_profile.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_fargate_profile)
        """

    def describe_identity_provider_config(
        self, **kwargs: Unpack[DescribeIdentityProviderConfigRequestTypeDef]
    ) -> DescribeIdentityProviderConfigResponseTypeDef:
        """
        Describes an identity provider configuration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_identity_provider_config.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_identity_provider_config)
        """

    def describe_insight(
        self, **kwargs: Unpack[DescribeInsightRequestTypeDef]
    ) -> DescribeInsightResponseTypeDef:
        """
        Returns details about an insight that you specify using its ID.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_insight.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_insight)
        """

    def describe_insights_refresh(
        self, **kwargs: Unpack[DescribeInsightsRefreshRequestTypeDef]
    ) -> DescribeInsightsRefreshResponseTypeDef:
        """
        Returns the status of the latest on-demand cluster insights refresh operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_insights_refresh.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_insights_refresh)
        """

    def describe_nodegroup(
        self, **kwargs: Unpack[DescribeNodegroupRequestTypeDef]
    ) -> DescribeNodegroupResponseTypeDef:
        """
        Describes a managed node group.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_nodegroup.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_nodegroup)
        """

    def describe_pod_identity_association(
        self, **kwargs: Unpack[DescribePodIdentityAssociationRequestTypeDef]
    ) -> DescribePodIdentityAssociationResponseTypeDef:
        """
        Returns descriptive information about an EKS Pod Identity association.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_pod_identity_association.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_pod_identity_association)
        """

    def describe_update(
        self, **kwargs: Unpack[DescribeUpdateRequestTypeDef]
    ) -> DescribeUpdateResponseTypeDef:
        """
        Describes an update to an Amazon EKS resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/describe_update.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#describe_update)
        """

    def disassociate_access_policy(
        self, **kwargs: Unpack[DisassociateAccessPolicyRequestTypeDef]
    ) -> dict[str, Any]:
        """
        Disassociates an access policy from an access entry.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/disassociate_access_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#disassociate_access_policy)
        """

    def disassociate_identity_provider_config(
        self, **kwargs: Unpack[DisassociateIdentityProviderConfigRequestTypeDef]
    ) -> DisassociateIdentityProviderConfigResponseTypeDef:
        """
        Disassociates an identity provider configuration from a cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/disassociate_identity_provider_config.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#disassociate_identity_provider_config)
        """

    def list_access_entries(
        self, **kwargs: Unpack[ListAccessEntriesRequestTypeDef]
    ) -> ListAccessEntriesResponseTypeDef:
        """
        Lists the access entries for your cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_access_entries.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_access_entries)
        """

    def list_access_policies(
        self, **kwargs: Unpack[ListAccessPoliciesRequestTypeDef]
    ) -> ListAccessPoliciesResponseTypeDef:
        """
        Lists the available access policies.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_access_policies.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_access_policies)
        """

    def list_addons(self, **kwargs: Unpack[ListAddonsRequestTypeDef]) -> ListAddonsResponseTypeDef:
        """
        Lists the installed add-ons.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_addons.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_addons)
        """

    def list_associated_access_policies(
        self, **kwargs: Unpack[ListAssociatedAccessPoliciesRequestTypeDef]
    ) -> ListAssociatedAccessPoliciesResponseTypeDef:
        """
        Lists the access policies associated with an access entry.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_associated_access_policies.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_associated_access_policies)
        """

    def list_capabilities(
        self, **kwargs: Unpack[ListCapabilitiesRequestTypeDef]
    ) -> ListCapabilitiesResponseTypeDef:
        """
        Lists all managed capabilities in your Amazon EKS cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_capabilities.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_capabilities)
        """

    def list_clusters(
        self, **kwargs: Unpack[ListClustersRequestTypeDef]
    ) -> ListClustersResponseTypeDef:
        """
        Lists the Amazon EKS clusters in your Amazon Web Services account in the
        specified Amazon Web Services Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_clusters.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_clusters)
        """

    def list_eks_anywhere_subscriptions(
        self, **kwargs: Unpack[ListEksAnywhereSubscriptionsRequestTypeDef]
    ) -> ListEksAnywhereSubscriptionsResponseTypeDef:
        """
        Displays the full description of the subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_eks_anywhere_subscriptions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_eks_anywhere_subscriptions)
        """

    def list_fargate_profiles(
        self, **kwargs: Unpack[ListFargateProfilesRequestTypeDef]
    ) -> ListFargateProfilesResponseTypeDef:
        """
        Lists the Fargate profiles associated with the specified cluster in your Amazon
        Web Services account in the specified Amazon Web Services Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_fargate_profiles.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_fargate_profiles)
        """

    def list_identity_provider_configs(
        self, **kwargs: Unpack[ListIdentityProviderConfigsRequestTypeDef]
    ) -> ListIdentityProviderConfigsResponseTypeDef:
        """
        Lists the identity provider configurations for your cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_identity_provider_configs.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_identity_provider_configs)
        """

    def list_insights(
        self, **kwargs: Unpack[ListInsightsRequestTypeDef]
    ) -> ListInsightsResponseTypeDef:
        """
        Returns a list of all insights checked for against the specified cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_insights.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_insights)
        """

    def list_nodegroups(
        self, **kwargs: Unpack[ListNodegroupsRequestTypeDef]
    ) -> ListNodegroupsResponseTypeDef:
        """
        Lists the managed node groups associated with the specified cluster in your
        Amazon Web Services account in the specified Amazon Web Services Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_nodegroups.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_nodegroups)
        """

    def list_pod_identity_associations(
        self, **kwargs: Unpack[ListPodIdentityAssociationsRequestTypeDef]
    ) -> ListPodIdentityAssociationsResponseTypeDef:
        """
        List the EKS Pod Identity associations in a cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_pod_identity_associations.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_pod_identity_associations)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        List the tags for an Amazon EKS resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_tags_for_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_tags_for_resource)
        """

    def list_updates(
        self, **kwargs: Unpack[ListUpdatesRequestTypeDef]
    ) -> ListUpdatesResponseTypeDef:
        """
        Lists the updates associated with an Amazon EKS resource in your Amazon Web
        Services account, in the specified Amazon Web Services Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/list_updates.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#list_updates)
        """

    def register_cluster(
        self, **kwargs: Unpack[RegisterClusterRequestTypeDef]
    ) -> RegisterClusterResponseTypeDef:
        """
        Connects a Kubernetes cluster to the Amazon EKS control plane.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/register_cluster.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#register_cluster)
        """

    def start_insights_refresh(
        self, **kwargs: Unpack[StartInsightsRefreshRequestTypeDef]
    ) -> StartInsightsRefreshResponseTypeDef:
        """
        Initiates an on-demand refresh operation for cluster insights, getting the
        latest analysis outside of the standard refresh schedule.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/start_insights_refresh.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#start_insights_refresh)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> dict[str, Any]:
        """
        Associates the specified tags to an Amazon EKS resource with the specified
        <code>resourceArn</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/tag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> dict[str, Any]:
        """
        Deletes specified tags from an Amazon EKS resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/untag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#untag_resource)
        """

    def update_access_entry(
        self, **kwargs: Unpack[UpdateAccessEntryRequestTypeDef]
    ) -> UpdateAccessEntryResponseTypeDef:
        """
        Updates an access entry.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_access_entry.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_access_entry)
        """

    def update_addon(
        self, **kwargs: Unpack[UpdateAddonRequestTypeDef]
    ) -> UpdateAddonResponseTypeDef:
        """
        Updates an Amazon EKS add-on.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_addon.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_addon)
        """

    def update_capability(
        self, **kwargs: Unpack[UpdateCapabilityRequestTypeDef]
    ) -> UpdateCapabilityResponseTypeDef:
        """
        Updates the configuration of a managed capability in your Amazon EKS cluster.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_capability.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_capability)
        """

    def update_cluster_config(
        self, **kwargs: Unpack[UpdateClusterConfigRequestTypeDef]
    ) -> UpdateClusterConfigResponseTypeDef:
        """
        Updates an Amazon EKS cluster configuration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_cluster_config.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_cluster_config)
        """

    def update_cluster_version(
        self, **kwargs: Unpack[UpdateClusterVersionRequestTypeDef]
    ) -> UpdateClusterVersionResponseTypeDef:
        """
        Updates an Amazon EKS cluster to the specified Kubernetes version.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_cluster_version.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_cluster_version)
        """

    def update_eks_anywhere_subscription(
        self, **kwargs: Unpack[UpdateEksAnywhereSubscriptionRequestTypeDef]
    ) -> UpdateEksAnywhereSubscriptionResponseTypeDef:
        """
        Update an EKS Anywhere Subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_eks_anywhere_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_eks_anywhere_subscription)
        """

    def update_nodegroup_config(
        self, **kwargs: Unpack[UpdateNodegroupConfigRequestTypeDef]
    ) -> UpdateNodegroupConfigResponseTypeDef:
        """
        Updates an Amazon EKS managed node group configuration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_nodegroup_config.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_nodegroup_config)
        """

    def update_nodegroup_version(
        self, **kwargs: Unpack[UpdateNodegroupVersionRequestTypeDef]
    ) -> UpdateNodegroupVersionResponseTypeDef:
        """
        Updates the Kubernetes version or AMI version of an Amazon EKS managed node
        group.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_nodegroup_version.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_nodegroup_version)
        """

    def update_pod_identity_association(
        self, **kwargs: Unpack[UpdatePodIdentityAssociationRequestTypeDef]
    ) -> UpdatePodIdentityAssociationResponseTypeDef:
        """
        Updates a EKS Pod Identity association.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/update_pod_identity_association.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#update_pod_identity_association)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["describe_addon_versions"]
    ) -> DescribeAddonVersionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["describe_cluster_versions"]
    ) -> DescribeClusterVersionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_access_entries"]
    ) -> ListAccessEntriesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_access_policies"]
    ) -> ListAccessPoliciesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_addons"]
    ) -> ListAddonsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_associated_access_policies"]
    ) -> ListAssociatedAccessPoliciesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_capabilities"]
    ) -> ListCapabilitiesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_clusters"]
    ) -> ListClustersPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_eks_anywhere_subscriptions"]
    ) -> ListEksAnywhereSubscriptionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_fargate_profiles"]
    ) -> ListFargateProfilesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_identity_provider_configs"]
    ) -> ListIdentityProviderConfigsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_insights"]
    ) -> ListInsightsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_nodegroups"]
    ) -> ListNodegroupsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_pod_identity_associations"]
    ) -> ListPodIdentityAssociationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_updates"]
    ) -> ListUpdatesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["addon_active"]
    ) -> AddonActiveWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["addon_deleted"]
    ) -> AddonDeletedWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["cluster_active"]
    ) -> ClusterActiveWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["cluster_deleted"]
    ) -> ClusterDeletedWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["fargate_profile_active"]
    ) -> FargateProfileActiveWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["fargate_profile_deleted"]
    ) -> FargateProfileDeletedWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["nodegroup_active"]
    ) -> NodegroupActiveWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """

    @overload  # type: ignore[override]
    def get_waiter(  # type: ignore[override]
        self, waiter_name: Literal["nodegroup_deleted"]
    ) -> NodegroupDeletedWaiter:
        """
        Returns an object that can wait for some condition.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/client/get_waiter.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/client/#get_waiter)
        """



"""
Main interface for eks service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/)

Copyright 2026 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_eks import (
        AddonActiveWaiter,
        AddonDeletedWaiter,
        Client,
        ClusterActiveWaiter,
        ClusterDeletedWaiter,
        DescribeAddonVersionsPaginator,
        DescribeClusterVersionsPaginator,
        EKSClient,
        FargateProfileActiveWaiter,
        FargateProfileDeletedWaiter,
        ListAccessEntriesPaginator,
        ListAccessPoliciesPaginator,
        ListAddonsPaginator,
        ListAssociatedAccessPoliciesPaginator,
        ListCapabilitiesPaginator,
        ListClustersPaginator,
        ListEksAnywhereSubscriptionsPaginator,
        ListFargateProfilesPaginator,
        ListIdentityProviderConfigsPaginator,
        ListInsightsPaginator,
        ListNodegroupsPaginator,
        ListPodIdentityAssociationsPaginator,
        ListUpdatesPaginator,
        NodegroupActiveWaiter,
        NodegroupDeletedWaiter,
    )

    session = Session()
    client: EKSClient = session.client("eks")

    addon_active_waiter: AddonActiveWaiter = client.get_waiter("addon_active")
    addon_deleted_waiter: AddonDeletedWaiter = client.get_waiter("addon_deleted")
    cluster_active_waiter: ClusterActiveWaiter = client.get_waiter("cluster_active")
    cluster_deleted_waiter: ClusterDeletedWaiter = client.get_waiter("cluster_deleted")
    fargate_profile_active_waiter: FargateProfileActiveWaiter = client.get_waiter("fargate_profile_active")
    fargate_profile_deleted_waiter: FargateProfileDeletedWaiter = client.get_waiter("fargate_profile_deleted")
    nodegroup_active_waiter: NodegroupActiveWaiter = client.get_waiter("nodegroup_active")
    nodegroup_deleted_waiter: NodegroupDeletedWaiter = client.get_waiter("nodegroup_deleted")

    describe_addon_versions_paginator: DescribeAddonVersionsPaginator = client.get_paginator("describe_addon_versions")
    describe_cluster_versions_paginator: DescribeClusterVersionsPaginator = client.get_paginator("describe_cluster_versions")
    list_access_entries_paginator: ListAccessEntriesPaginator = client.get_paginator("list_access_entries")
    list_access_policies_paginator: ListAccessPoliciesPaginator = client.get_paginator("list_access_policies")
    list_addons_paginator: ListAddonsPaginator = client.get_paginator("list_addons")
    list_associated_access_policies_paginator: ListAssociatedAccessPoliciesPaginator = client.get_paginator("list_associated_access_policies")
    list_capabilities_paginator: ListCapabilitiesPaginator = client.get_paginator("list_capabilities")
    list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
    list_eks_anywhere_subscriptions_paginator: ListEksAnywhereSubscriptionsPaginator = client.get_paginator("list_eks_anywhere_subscriptions")
    list_fargate_profiles_paginator: ListFargateProfilesPaginator = client.get_paginator("list_fargate_profiles")
    list_identity_provider_configs_paginator: ListIdentityProviderConfigsPaginator = client.get_paginator("list_identity_provider_configs")
    list_insights_paginator: ListInsightsPaginator = client.get_paginator("list_insights")
    list_nodegroups_paginator: ListNodegroupsPaginator = client.get_paginator("list_nodegroups")
    list_pod_identity_associations_paginator: ListPodIdentityAssociationsPaginator = client.get_paginator("list_pod_identity_associations")
    list_updates_paginator: ListUpdatesPaginator = client.get_paginator("list_updates")
    ```
"""

from .client import EKSClient
from .paginator import (
    DescribeAddonVersionsPaginator,
    DescribeClusterVersionsPaginator,
    ListAccessEntriesPaginator,
    ListAccessPoliciesPaginator,
    ListAddonsPaginator,
    ListAssociatedAccessPoliciesPaginator,
    ListCapabilitiesPaginator,
    ListClustersPaginator,
    ListEksAnywhereSubscriptionsPaginator,
    ListFargateProfilesPaginator,
    ListIdentityProviderConfigsPaginator,
    ListInsightsPaginator,
    ListNodegroupsPaginator,
    ListPodIdentityAssociationsPaginator,
    ListUpdatesPaginator,
)
from .waiter import (
    AddonActiveWaiter,
    AddonDeletedWaiter,
    ClusterActiveWaiter,
    ClusterDeletedWaiter,
    FargateProfileActiveWaiter,
    FargateProfileDeletedWaiter,
    NodegroupActiveWaiter,
    NodegroupDeletedWaiter,
)

Client = EKSClient


__all__ = (
    "AddonActiveWaiter",
    "AddonDeletedWaiter",
    "Client",
    "ClusterActiveWaiter",
    "ClusterDeletedWaiter",
    "DescribeAddonVersionsPaginator",
    "DescribeClusterVersionsPaginator",
    "EKSClient",
    "FargateProfileActiveWaiter",
    "FargateProfileDeletedWaiter",
    "ListAccessEntriesPaginator",
    "ListAccessPoliciesPaginator",
    "ListAddonsPaginator",
    "ListAssociatedAccessPoliciesPaginator",
    "ListCapabilitiesPaginator",
    "ListClustersPaginator",
    "ListEksAnywhereSubscriptionsPaginator",
    "ListFargateProfilesPaginator",
    "ListIdentityProviderConfigsPaginator",
    "ListInsightsPaginator",
    "ListNodegroupsPaginator",
    "ListPodIdentityAssociationsPaginator",
    "ListUpdatesPaginator",
    "NodegroupActiveWaiter",
    "NodegroupDeletedWaiter",
)



"""
Type annotations for eks service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/)

Copyright 2026 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_eks.client import EKSClient
    from types_boto3_eks.paginator import (
        DescribeAddonVersionsPaginator,
        DescribeClusterVersionsPaginator,
        ListAccessEntriesPaginator,
        ListAccessPoliciesPaginator,
        ListAddonsPaginator,
        ListAssociatedAccessPoliciesPaginator,
        ListCapabilitiesPaginator,
        ListClustersPaginator,
        ListEksAnywhereSubscriptionsPaginator,
        ListFargateProfilesPaginator,
        ListIdentityProviderConfigsPaginator,
        ListInsightsPaginator,
        ListNodegroupsPaginator,
        ListPodIdentityAssociationsPaginator,
        ListUpdatesPaginator,
    )

    session = Session()
    client: EKSClient = session.client("eks")

    describe_addon_versions_paginator: DescribeAddonVersionsPaginator = client.get_paginator("describe_addon_versions")
    describe_cluster_versions_paginator: DescribeClusterVersionsPaginator = client.get_paginator("describe_cluster_versions")
    list_access_entries_paginator: ListAccessEntriesPaginator = client.get_paginator("list_access_entries")
    list_access_policies_paginator: ListAccessPoliciesPaginator = client.get_paginator("list_access_policies")
    list_addons_paginator: ListAddonsPaginator = client.get_paginator("list_addons")
    list_associated_access_policies_paginator: ListAssociatedAccessPoliciesPaginator = client.get_paginator("list_associated_access_policies")
    list_capabilities_paginator: ListCapabilitiesPaginator = client.get_paginator("list_capabilities")
    list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
    list_eks_anywhere_subscriptions_paginator: ListEksAnywhereSubscriptionsPaginator = client.get_paginator("list_eks_anywhere_subscriptions")
    list_fargate_profiles_paginator: ListFargateProfilesPaginator = client.get_paginator("list_fargate_profiles")
    list_identity_provider_configs_paginator: ListIdentityProviderConfigsPaginator = client.get_paginator("list_identity_provider_configs")
    list_insights_paginator: ListInsightsPaginator = client.get_paginator("list_insights")
    list_nodegroups_paginator: ListNodegroupsPaginator = client.get_paginator("list_nodegroups")
    list_pod_identity_associations_paginator: ListPodIdentityAssociationsPaginator = client.get_paginator("list_pod_identity_associations")
    list_updates_paginator: ListUpdatesPaginator = client.get_paginator("list_updates")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    DescribeAddonVersionsRequestPaginateTypeDef,
    DescribeAddonVersionsResponseTypeDef,
    DescribeClusterVersionsRequestPaginateTypeDef,
    DescribeClusterVersionsResponseTypeDef,
    ListAccessEntriesRequestPaginateTypeDef,
    ListAccessEntriesResponseTypeDef,
    ListAccessPoliciesRequestPaginateTypeDef,
    ListAccessPoliciesResponseTypeDef,
    ListAddonsRequestPaginateTypeDef,
    ListAddonsResponseTypeDef,
    ListAssociatedAccessPoliciesRequestPaginateTypeDef,
    ListAssociatedAccessPoliciesResponseTypeDef,
    ListCapabilitiesRequestPaginateTypeDef,
    ListCapabilitiesResponseTypeDef,
    ListClustersRequestPaginateTypeDef,
    ListClustersResponseTypeDef,
    ListEksAnywhereSubscriptionsRequestPaginateTypeDef,
    ListEksAnywhereSubscriptionsResponseTypeDef,
    ListFargateProfilesRequestPaginateTypeDef,
    ListFargateProfilesResponseTypeDef,
    ListIdentityProviderConfigsRequestPaginateTypeDef,
    ListIdentityProviderConfigsResponseTypeDef,
    ListInsightsRequestPaginateTypeDef,
    ListInsightsResponseTypeDef,
    ListNodegroupsRequestPaginateTypeDef,
    ListNodegroupsResponseTypeDef,
    ListPodIdentityAssociationsRequestPaginateTypeDef,
    ListPodIdentityAssociationsResponseTypeDef,
    ListUpdatesRequestPaginateTypeDef,
    ListUpdatesResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "DescribeAddonVersionsPaginator",
    "DescribeClusterVersionsPaginator",
    "ListAccessEntriesPaginator",
    "ListAccessPoliciesPaginator",
    "ListAddonsPaginator",
    "ListAssociatedAccessPoliciesPaginator",
    "ListCapabilitiesPaginator",
    "ListClustersPaginator",
    "ListEksAnywhereSubscriptionsPaginator",
    "ListFargateProfilesPaginator",
    "ListIdentityProviderConfigsPaginator",
    "ListInsightsPaginator",
    "ListNodegroupsPaginator",
    "ListPodIdentityAssociationsPaginator",
    "ListUpdatesPaginator",
)


if TYPE_CHECKING:
    _DescribeAddonVersionsPaginatorBase = Paginator[DescribeAddonVersionsResponseTypeDef]
else:
    _DescribeAddonVersionsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeAddonVersionsPaginator(_DescribeAddonVersionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/DescribeAddonVersions.html#EKS.Paginator.DescribeAddonVersions)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#describeaddonversionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAddonVersionsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeAddonVersionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/DescribeAddonVersions.html#EKS.Paginator.DescribeAddonVersions.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#describeaddonversionspaginator)
        """


if TYPE_CHECKING:
    _DescribeClusterVersionsPaginatorBase = Paginator[DescribeClusterVersionsResponseTypeDef]
else:
    _DescribeClusterVersionsPaginatorBase = Paginator  # type: ignore[assignment]


class DescribeClusterVersionsPaginator(_DescribeClusterVersionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/DescribeClusterVersions.html#EKS.Paginator.DescribeClusterVersions)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#describeclusterversionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeClusterVersionsRequestPaginateTypeDef]
    ) -> PageIterator[DescribeClusterVersionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/DescribeClusterVersions.html#EKS.Paginator.DescribeClusterVersions.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#describeclusterversionspaginator)
        """


if TYPE_CHECKING:
    _ListAccessEntriesPaginatorBase = Paginator[ListAccessEntriesResponseTypeDef]
else:
    _ListAccessEntriesPaginatorBase = Paginator  # type: ignore[assignment]


class ListAccessEntriesPaginator(_ListAccessEntriesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAccessEntries.html#EKS.Paginator.ListAccessEntries)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listaccessentriespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAccessEntriesRequestPaginateTypeDef]
    ) -> PageIterator[ListAccessEntriesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAccessEntries.html#EKS.Paginator.ListAccessEntries.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listaccessentriespaginator)
        """


if TYPE_CHECKING:
    _ListAccessPoliciesPaginatorBase = Paginator[ListAccessPoliciesResponseTypeDef]
else:
    _ListAccessPoliciesPaginatorBase = Paginator  # type: ignore[assignment]


class ListAccessPoliciesPaginator(_ListAccessPoliciesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAccessPolicies.html#EKS.Paginator.ListAccessPolicies)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listaccesspoliciespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAccessPoliciesRequestPaginateTypeDef]
    ) -> PageIterator[ListAccessPoliciesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAccessPolicies.html#EKS.Paginator.ListAccessPolicies.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listaccesspoliciespaginator)
        """


if TYPE_CHECKING:
    _ListAddonsPaginatorBase = Paginator[ListAddonsResponseTypeDef]
else:
    _ListAddonsPaginatorBase = Paginator  # type: ignore[assignment]


class ListAddonsPaginator(_ListAddonsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAddons.html#EKS.Paginator.ListAddons)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listaddonspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAddonsRequestPaginateTypeDef]
    ) -> PageIterator[ListAddonsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAddons.html#EKS.Paginator.ListAddons.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listaddonspaginator)
        """


if TYPE_CHECKING:
    _ListAssociatedAccessPoliciesPaginatorBase = Paginator[
        ListAssociatedAccessPoliciesResponseTypeDef
    ]
else:
    _ListAssociatedAccessPoliciesPaginatorBase = Paginator  # type: ignore[assignment]


class ListAssociatedAccessPoliciesPaginator(_ListAssociatedAccessPoliciesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAssociatedAccessPolicies.html#EKS.Paginator.ListAssociatedAccessPolicies)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listassociatedaccesspoliciespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListAssociatedAccessPoliciesRequestPaginateTypeDef]
    ) -> PageIterator[ListAssociatedAccessPoliciesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListAssociatedAccessPolicies.html#EKS.Paginator.ListAssociatedAccessPolicies.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listassociatedaccesspoliciespaginator)
        """


if TYPE_CHECKING:
    _ListCapabilitiesPaginatorBase = Paginator[ListCapabilitiesResponseTypeDef]
else:
    _ListCapabilitiesPaginatorBase = Paginator  # type: ignore[assignment]


class ListCapabilitiesPaginator(_ListCapabilitiesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListCapabilities.html#EKS.Paginator.ListCapabilities)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listcapabilitiespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListCapabilitiesRequestPaginateTypeDef]
    ) -> PageIterator[ListCapabilitiesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListCapabilities.html#EKS.Paginator.ListCapabilities.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listcapabilitiespaginator)
        """


if TYPE_CHECKING:
    _ListClustersPaginatorBase = Paginator[ListClustersResponseTypeDef]
else:
    _ListClustersPaginatorBase = Paginator  # type: ignore[assignment]


class ListClustersPaginator(_ListClustersPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListClusters.html#EKS.Paginator.ListClusters)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listclusterspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListClustersRequestPaginateTypeDef]
    ) -> PageIterator[ListClustersResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListClusters.html#EKS.Paginator.ListClusters.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listclusterspaginator)
        """


if TYPE_CHECKING:
    _ListEksAnywhereSubscriptionsPaginatorBase = Paginator[
        ListEksAnywhereSubscriptionsResponseTypeDef
    ]
else:
    _ListEksAnywhereSubscriptionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListEksAnywhereSubscriptionsPaginator(_ListEksAnywhereSubscriptionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListEksAnywhereSubscriptions.html#EKS.Paginator.ListEksAnywhereSubscriptions)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listeksanywheresubscriptionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListEksAnywhereSubscriptionsRequestPaginateTypeDef]
    ) -> PageIterator[ListEksAnywhereSubscriptionsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListEksAnywhereSubscriptions.html#EKS.Paginator.ListEksAnywhereSubscriptions.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listeksanywheresubscriptionspaginator)
        """


if TYPE_CHECKING:
    _ListFargateProfilesPaginatorBase = Paginator[ListFargateProfilesResponseTypeDef]
else:
    _ListFargateProfilesPaginatorBase = Paginator  # type: ignore[assignment]


class ListFargateProfilesPaginator(_ListFargateProfilesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListFargateProfiles.html#EKS.Paginator.ListFargateProfiles)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listfargateprofilespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListFargateProfilesRequestPaginateTypeDef]
    ) -> PageIterator[ListFargateProfilesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListFargateProfiles.html#EKS.Paginator.ListFargateProfiles.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listfargateprofilespaginator)
        """


if TYPE_CHECKING:
    _ListIdentityProviderConfigsPaginatorBase = Paginator[
        ListIdentityProviderConfigsResponseTypeDef
    ]
else:
    _ListIdentityProviderConfigsPaginatorBase = Paginator  # type: ignore[assignment]


class ListIdentityProviderConfigsPaginator(_ListIdentityProviderConfigsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListIdentityProviderConfigs.html#EKS.Paginator.ListIdentityProviderConfigs)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listidentityproviderconfigspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListIdentityProviderConfigsRequestPaginateTypeDef]
    ) -> PageIterator[ListIdentityProviderConfigsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListIdentityProviderConfigs.html#EKS.Paginator.ListIdentityProviderConfigs.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listidentityproviderconfigspaginator)
        """


if TYPE_CHECKING:
    _ListInsightsPaginatorBase = Paginator[ListInsightsResponseTypeDef]
else:
    _ListInsightsPaginatorBase = Paginator  # type: ignore[assignment]


class ListInsightsPaginator(_ListInsightsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListInsights.html#EKS.Paginator.ListInsights)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listinsightspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListInsightsRequestPaginateTypeDef]
    ) -> PageIterator[ListInsightsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListInsights.html#EKS.Paginator.ListInsights.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listinsightspaginator)
        """


if TYPE_CHECKING:
    _ListNodegroupsPaginatorBase = Paginator[ListNodegroupsResponseTypeDef]
else:
    _ListNodegroupsPaginatorBase = Paginator  # type: ignore[assignment]


class ListNodegroupsPaginator(_ListNodegroupsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListNodegroups.html#EKS.Paginator.ListNodegroups)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listnodegroupspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListNodegroupsRequestPaginateTypeDef]
    ) -> PageIterator[ListNodegroupsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListNodegroups.html#EKS.Paginator.ListNodegroups.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listnodegroupspaginator)
        """


if TYPE_CHECKING:
    _ListPodIdentityAssociationsPaginatorBase = Paginator[
        ListPodIdentityAssociationsResponseTypeDef
    ]
else:
    _ListPodIdentityAssociationsPaginatorBase = Paginator  # type: ignore[assignment]


class ListPodIdentityAssociationsPaginator(_ListPodIdentityAssociationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListPodIdentityAssociations.html#EKS.Paginator.ListPodIdentityAssociations)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listpodidentityassociationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListPodIdentityAssociationsRequestPaginateTypeDef]
    ) -> PageIterator[ListPodIdentityAssociationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListPodIdentityAssociations.html#EKS.Paginator.ListPodIdentityAssociations.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listpodidentityassociationspaginator)
        """


if TYPE_CHECKING:
    _ListUpdatesPaginatorBase = Paginator[ListUpdatesResponseTypeDef]
else:
    _ListUpdatesPaginatorBase = Paginator  # type: ignore[assignment]


class ListUpdatesPaginator(_ListUpdatesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListUpdates.html#EKS.Paginator.ListUpdates)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listupdatespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListUpdatesRequestPaginateTypeDef]
    ) -> PageIterator[ListUpdatesResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/paginator/ListUpdates.html#EKS.Paginator.ListUpdates.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/paginators/#listupdatespaginator)
        """



"""
Type annotations for eks service client waiters.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/)

Copyright 2026 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_eks.client import EKSClient
    from types_boto3_eks.waiter import (
        AddonActiveWaiter,
        AddonDeletedWaiter,
        ClusterActiveWaiter,
        ClusterDeletedWaiter,
        FargateProfileActiveWaiter,
        FargateProfileDeletedWaiter,
        NodegroupActiveWaiter,
        NodegroupDeletedWaiter,
    )

    session = Session()
    client: EKSClient = session.client("eks")

    addon_active_waiter: AddonActiveWaiter = client.get_waiter("addon_active")
    addon_deleted_waiter: AddonDeletedWaiter = client.get_waiter("addon_deleted")
    cluster_active_waiter: ClusterActiveWaiter = client.get_waiter("cluster_active")
    cluster_deleted_waiter: ClusterDeletedWaiter = client.get_waiter("cluster_deleted")
    fargate_profile_active_waiter: FargateProfileActiveWaiter = client.get_waiter("fargate_profile_active")
    fargate_profile_deleted_waiter: FargateProfileDeletedWaiter = client.get_waiter("fargate_profile_deleted")
    nodegroup_active_waiter: NodegroupActiveWaiter = client.get_waiter("nodegroup_active")
    nodegroup_deleted_waiter: NodegroupDeletedWaiter = client.get_waiter("nodegroup_deleted")
    ```
"""

from __future__ import annotations

import sys

from botocore.waiter import Waiter

from .type_defs import (
    DescribeAddonRequestWaitExtraTypeDef,
    DescribeAddonRequestWaitTypeDef,
    DescribeClusterRequestWaitExtraTypeDef,
    DescribeClusterRequestWaitTypeDef,
    DescribeFargateProfileRequestWaitExtraTypeDef,
    DescribeFargateProfileRequestWaitTypeDef,
    DescribeNodegroupRequestWaitExtraTypeDef,
    DescribeNodegroupRequestWaitTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = (
    "AddonActiveWaiter",
    "AddonDeletedWaiter",
    "ClusterActiveWaiter",
    "ClusterDeletedWaiter",
    "FargateProfileActiveWaiter",
    "FargateProfileDeletedWaiter",
    "NodegroupActiveWaiter",
    "NodegroupDeletedWaiter",
)

class AddonActiveWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/AddonActive.html#EKS.Waiter.AddonActive)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#addonactivewaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAddonRequestWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/AddonActive.html#EKS.Waiter.AddonActive.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#addonactivewaiter)
        """

class AddonDeletedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/AddonDeleted.html#EKS.Waiter.AddonDeleted)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#addondeletedwaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeAddonRequestWaitExtraTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/AddonDeleted.html#EKS.Waiter.AddonDeleted.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#addondeletedwaiter)
        """

class ClusterActiveWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/ClusterActive.html#EKS.Waiter.ClusterActive)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#clusteractivewaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeClusterRequestWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/ClusterActive.html#EKS.Waiter.ClusterActive.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#clusteractivewaiter)
        """

class ClusterDeletedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/ClusterDeleted.html#EKS.Waiter.ClusterDeleted)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#clusterdeletedwaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeClusterRequestWaitExtraTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/ClusterDeleted.html#EKS.Waiter.ClusterDeleted.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#clusterdeletedwaiter)
        """

class FargateProfileActiveWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/FargateProfileActive.html#EKS.Waiter.FargateProfileActive)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#fargateprofileactivewaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeFargateProfileRequestWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/FargateProfileActive.html#EKS.Waiter.FargateProfileActive.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#fargateprofileactivewaiter)
        """

class FargateProfileDeletedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/FargateProfileDeleted.html#EKS.Waiter.FargateProfileDeleted)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#fargateprofiledeletedwaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeFargateProfileRequestWaitExtraTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/FargateProfileDeleted.html#EKS.Waiter.FargateProfileDeleted.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#fargateprofiledeletedwaiter)
        """

class NodegroupActiveWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/NodegroupActive.html#EKS.Waiter.NodegroupActive)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#nodegroupactivewaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeNodegroupRequestWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/NodegroupActive.html#EKS.Waiter.NodegroupActive.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#nodegroupactivewaiter)
        """

class NodegroupDeletedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/NodegroupDeleted.html#EKS.Waiter.NodegroupDeleted)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#nodegroupdeletedwaiter)
    """
    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeNodegroupRequestWaitExtraTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/eks/waiter/NodegroupDeleted.html#EKS.Waiter.NodegroupDeleted.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/waiters/#nodegroupdeletedwaiter)
        """



"""
Type annotations for eks service literal definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_eks/literals/)

Copyright 2026 Vlad Emelianov

Usage::

    ```python
    from types_boto3_eks.literals import AMITypesType

    data: AMITypesType = "AL2023_ARM_64_NVIDIA"
    ```
"""

import sys

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = (
    "AMITypesType",
    "AccessScopeTypeType",
    "AddonActiveWaiterName",
    "AddonDeletedWaiterName",
    "AddonIssueCodeType",
    "AddonStatusType",
    "ArgoCdRoleType",
    "AuthenticationModeType",
    "CapabilityDeletePropagationPolicyType",
    "CapabilityIssueCodeType",
    "CapabilityStatusType",
    "CapabilityTypeType",
    "CapacityTypesType",
    "CategoryType",
    "ClusterActiveWaiterName",
    "ClusterDeletedWaiterName",
    "ClusterIssueCodeType",
    "ClusterStatusType",
    "ClusterVersionStatusType",
    "ConfigStatusType",
    "ConnectorConfigProviderType",
    "DescribeAddonVersionsPaginatorName",
    "DescribeClusterVersionsPaginatorName",
    "EKSServiceName",
    "EksAnywhereSubscriptionLicenseTypeType",
    "EksAnywhereSubscriptionStatusType",
    "EksAnywhereSubscriptionTermUnitType",
    "ErrorCodeType",
    "FargateProfileActiveWaiterName",
    "FargateProfileDeletedWaiterName",
    "FargateProfileIssueCodeType",
    "FargateProfileStatusType",
    "InsightStatusValueType",
    "InsightsRefreshStatusType",
    "IpFamilyType",
    "ListAccessEntriesPaginatorName",
    "ListAccessPoliciesPaginatorName",
    "ListAddonsPaginatorName",
    "ListAssociatedAccessPoliciesPaginatorName",
    "ListCapabilitiesPaginatorName",
    "ListClustersPaginatorName",
    "ListEksAnywhereSubscriptionsPaginatorName",
    "ListFargateProfilesPaginatorName",
    "ListIdentityProviderConfigsPaginatorName",
    "ListInsightsPaginatorName",
    "ListNodegroupsPaginatorName",
    "ListPodIdentityAssociationsPaginatorName",
    "ListUpdatesPaginatorName",
    "LogTypeType",
    "NodegroupActiveWaiterName",
    "NodegroupDeletedWaiterName",
    "NodegroupIssueCodeType",
    "NodegroupStatusType",
    "NodegroupUpdateStrategiesType",
    "PaginatorName",
    "ProvisionedControlPlaneTierType",
    "RegionName",
    "RepairActionType",
    "ResolveConflictsType",
    "ResourceServiceName",
    "ServiceName",
    "SsoIdentityTypeType",
    "SupportTypeType",
    "TaintEffectType",
    "UpdateParamTypeType",
    "UpdateStatusType",
    "UpdateTypeType",
    "VersionStatusType",
    "WaiterName",
)

AMITypesType = Literal[
    "AL2023_ARM_64_NVIDIA",
    "AL2023_ARM_64_STANDARD",
    "AL2023_x86_64_NEURON",
    "AL2023_x86_64_NVIDIA",
    "AL2023_x86_64_STANDARD",
    "AL2_ARM_64",
    "AL2_x86_64",
    "AL2_x86_64_GPU",
    "BOTTLEROCKET_ARM_64",
    "BOTTLEROCKET_ARM_64_FIPS",
    "BOTTLEROCKET_ARM_64_NVIDIA",
    "BOTTLEROCKET_ARM_64_NVIDIA_FIPS",
    "BOTTLEROCKET_x86_64",
    "BOTTLEROCKET_x86_64_FIPS",
    "BOTTLEROCKET_x86_64_NVIDIA",
    "BOTTLEROCKET_x86_64_NVIDIA_FIPS",
    "CUSTOM",
    "WINDOWS_CORE_2019_x86_64",
    "WINDOWS_CORE_2022_x86_64",
    "WINDOWS_FULL_2019_x86_64",
    "WINDOWS_FULL_2022_x86_64",
]
AccessScopeTypeType = Literal["cluster", "namespace"]
AddonActiveWaiterName = Literal["addon_active"]
AddonDeletedWaiterName = Literal["addon_deleted"]
AddonIssueCodeType = Literal[
    "AccessDenied",
    "AddonPermissionFailure",
    "AddonSubscriptionNeeded",
    "AdmissionRequestDenied",
    "ClusterUnreachable",
    "ConfigurationConflict",
    "InsufficientNumberOfReplicas",
    "InternalFailure",
    "K8sResourceNotFound",
    "UnsupportedAddonModification",
]
AddonStatusType = Literal[
    "ACTIVE",
    "CREATE_FAILED",
    "CREATING",
    "DEGRADED",
    "DELETE_FAILED",
    "DELETING",
    "UPDATE_FAILED",
    "UPDATING",
]
ArgoCdRoleType = Literal["ADMIN", "EDITOR", "VIEWER"]
AuthenticationModeType = Literal["API", "API_AND_CONFIG_MAP", "CONFIG_MAP"]
CapabilityDeletePropagationPolicyType = Literal["RETAIN"]
CapabilityIssueCodeType = Literal["AccessDenied", "ClusterUnreachable"]
CapabilityStatusType = Literal[
    "ACTIVE", "CREATE_FAILED", "CREATING", "DEGRADED", "DELETE_FAILED", "DELETING", "UPDATING"
]
CapabilityTypeType = Literal["ACK", "ARGOCD", "KRO"]
CapacityTypesType = Literal["CAPACITY_BLOCK", "ON_DEMAND", "SPOT"]
CategoryType = Literal["MISCONFIGURATION", "UPGRADE_READINESS"]
ClusterActiveWaiterName = Literal["cluster_active"]
ClusterDeletedWaiterName = Literal["cluster_deleted"]
ClusterIssueCodeType = Literal[
    "AccessDenied",
    "ClusterUnreachable",
    "ConfigurationConflict",
    "Ec2SecurityGroupNotFound",
    "Ec2ServiceNotSubscribed",
    "Ec2SubnetNotFound",
    "IamRoleNotFound",
    "InsufficientFreeAddresses",
    "InternalFailure",
    "KmsGrantRevoked",
    "KmsKeyDisabled",
    "KmsKeyMarkedForDeletion",
    "KmsKeyNotFound",
    "Other",
    "ResourceLimitExceeded",
    "ResourceNotFound",
    "StsRegionalEndpointDisabled",
    "UnsupportedVersion",
    "VpcNotFound",
]
ClusterStatusType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "PENDING", "UPDATING"]
ClusterVersionStatusType = Literal["extended-support", "standard-support", "unsupported"]
ConfigStatusType = Literal["ACTIVE", "CREATING", "DELETING"]
ConnectorConfigProviderType = Literal[
    "AKS", "ANTHOS", "EC2", "EKS_ANYWHERE", "GKE", "OPENSHIFT", "OTHER", "RANCHER", "TANZU"
]
DescribeAddonVersionsPaginatorName = Literal["describe_addon_versions"]
DescribeClusterVersionsPaginatorName = Literal["describe_cluster_versions"]
EksAnywhereSubscriptionLicenseTypeType = Literal["Cluster"]
EksAnywhereSubscriptionStatusType = Literal[
    "ACTIVE", "CREATING", "DELETING", "EXPIRED", "EXPIRING", "UPDATING"
]
EksAnywhereSubscriptionTermUnitType = Literal["MONTHS"]
ErrorCodeType = Literal[
    "AccessDenied",
    "AdmissionRequestDenied",
    "ClusterUnreachable",
    "ConfigurationConflict",
    "EniLimitReached",
    "InsufficientFreeAddresses",
    "InsufficientNumberOfReplicas",
    "IpNotAvailable",
    "K8sResourceNotFound",
    "NodeCreationFailure",
    "OperationNotPermitted",
    "PodEvictionFailure",
    "SecurityGroupNotFound",
    "SubnetNotFound",
    "Unknown",
    "UnsupportedAddonModification",
    "VpcIdNotFound",
]
FargateProfileActiveWaiterName = Literal["fargate_profile_active"]
FargateProfileDeletedWaiterName = Literal["fargate_profile_deleted"]
FargateProfileIssueCodeType = Literal[
    "AccessDenied", "ClusterUnreachable", "InternalFailure", "PodExecutionRoleAlreadyInUse"
]
FargateProfileStatusType = Literal[
    "ACTIVE", "CREATE_FAILED", "CREATING", "DELETE_FAILED", "DELETING"
]
InsightStatusValueType = Literal["ERROR", "PASSING", "UNKNOWN", "WARNING"]
InsightsRefreshStatusType = Literal["COMPLETED", "FAILED", "IN_PROGRESS"]
IpFamilyType = Literal["ipv4", "ipv6"]
ListAccessEntriesPaginatorName = Literal["list_access_entries"]
ListAccessPoliciesPaginatorName = Literal["list_access_policies"]
ListAddonsPaginatorName = Literal["list_addons"]
ListAssociatedAccessPoliciesPaginatorName = Literal["list_associated_access_policies"]
ListCapabilitiesPaginatorName = Literal["list_capabilities"]
ListClustersPaginatorName = Literal["list_clusters"]
ListEksAnywhereSubscriptionsPaginatorName = Literal["list_eks_anywhere_subscriptions"]
ListFargateProfilesPaginatorName = Literal["list_fargate_profiles"]
ListIdentityProviderConfigsPaginatorName = Literal["list_identity_provider_configs"]
ListInsightsPaginatorName = Literal["list_insights"]
ListNodegroupsPaginatorName = Literal["list_nodegroups"]
ListPodIdentityAssociationsPaginatorName = Literal["list_pod_identity_associations"]
ListUpdatesPaginatorName = Literal["list_updates"]
LogTypeType = Literal["api", "audit", "authenticator", "controllerManager", "scheduler"]
NodegroupActiveWaiterName = Literal["nodegroup_active"]
NodegroupDeletedWaiterName = Literal["nodegroup_deleted"]
NodegroupIssueCodeType = Literal[
    "AccessDenied",
    "AmiIdNotFound",
    "AsgInstanceLaunchFailures",
    "AutoScalingGroupInstanceRefreshActive",
    "AutoScalingGroupInvalidConfiguration",
    "AutoScalingGroupNotFound",
    "AutoScalingGroupOptInRequired",
    "AutoScalingGroupRateLimitExceeded",
    "ClusterUnreachable",
    "Ec2InstanceTypeDoesNotExist",
    "Ec2LaunchTemplateDeletionFailure",
    "Ec2LaunchTemplateInvalidConfiguration",
    "Ec2LaunchTemplateMaxLimitExceeded",
    "Ec2LaunchTemplateNotFound",
    "Ec2LaunchTemplateVersionMaxLimitExceeded",
    "Ec2LaunchTemplateVersionMismatch",
    "Ec2SecurityGroupDeletionFailure",
    "Ec2SecurityGroupNotFound",
    "Ec2SubnetInvalidConfiguration",
    "Ec2SubnetListTooLong",
    "Ec2SubnetMissingIpv6Assignment",
    "Ec2SubnetNotFound",
    "IamInstanceProfileNotFound",
    "IamLimitExceeded",
    "IamNodeRoleNotFound",
    "IamThrottling",
    "InstanceLimitExceeded",
    "InsufficientFreeAddresses",
    "InternalFailure",
    "KubernetesLabelInvalid",
    "LimitExceeded",
    "NodeCreationFailure",
    "NodeTerminationFailure",
    "PodEvictionFailure",
    "SourceEc2LaunchTemplateNotFound",
    "Unknown",
]
NodegroupStatusType = Literal[
    "ACTIVE", "CREATE_FAILED", "CREATING", "DEGRADED", "DELETE_FAILED", "DELETING", "UPDATING"
]
NodegroupUpdateStrategiesType = Literal["DEFAULT", "MINIMAL"]
ProvisionedControlPlaneTierType = Literal["standard", "tier-2xl", "tier-4xl", "tier-xl"]
RepairActionType = Literal["NoAction", "Reboot", "Replace"]
ResolveConflictsType = Literal["NONE", "OVERWRITE", "PRESERVE"]
SsoIdentityTypeType = Literal["SSO_GROUP", "SSO_USER"]
SupportTypeType = Literal["EXTENDED", "STANDARD"]
TaintEffectType = Literal["NO_EXECUTE", "NO_SCHEDULE", "PREFER_NO_SCHEDULE"]
UpdateParamTypeType = Literal[
    "AddonVersion",
    "AuthenticationMode",
    "ClusterLogging",
    "ComputeConfig",
    "ConfigurationValues",
    "DeletionProtection",
    "DesiredSize",
    "EncryptionConfig",
    "EndpointPrivateAccess",
    "EndpointPublicAccess",
    "IdentityProviderConfig",
    "KubernetesNetworkConfig",
    "LabelsToAdd",
    "LabelsToRemove",
    "LaunchTemplateName",
    "LaunchTemplateVersion",
    "MaxSize",
    "MaxUnavailable",
    "MaxUnavailablePercentage",
    "MinSize",
    "NodeRepairConfig",
    "NodeRepairEnabled",
    "PlatformVersion",
    "PodIdentityAssociations",
    "PreviousTier",
    "PublicAccessCidrs",
    "ReleaseVersion",
    "RemoteNetworkConfig",
    "ResolveConflicts",
    "SecurityGroups",
    "ServiceAccountRoleArn",
    "StorageConfig",
    "Subnets",
    "TaintsToAdd",
    "TaintsToRemove",
    "UpdateStrategy",
    "UpdatedTier",
    "UpgradePolicy",
    "Version",
    "ZonalShiftConfig",
]
UpdateStatusType = Literal["Cancelled", "Failed", "InProgress", "Successful"]
UpdateTypeType = Literal[
    "AccessConfigUpdate",
    "AddonUpdate",
    "AssociateEncryptionConfig",
    "AssociateIdentityProviderConfig",
    "AutoModeUpdate",
    "ConfigUpdate",
    "ControlPlaneScalingConfigUpdate",
    "DeletionProtectionUpdate",
    "DisassociateIdentityProviderConfig",
    "EndpointAccessUpdate",
    "LoggingUpdate",
    "RemoteNetworkConfigUpdate",
    "UpgradePolicyUpdate",
    "VendedLogsUpdate",
    "VersionUpdate",
    "VpcConfigUpdate",
    "ZonalShiftConfigUpdate",
]
VersionStatusType = Literal["EXTENDED_SUPPORT", "STANDARD_SUPPORT", "UNSUPPORTED"]
EKSServiceName = Literal["eks"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "aiops",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appfabric",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "application-signals",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "arc-region-switch",
    "arc-zonal-shift",
    "artifact",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "b2bi",
    "backup",
    "backup-gateway",
    "backupsearch",
    "batch",
    "bcm-dashboards",
    "bcm-data-exports",
    "bcm-pricing-calculator",
    "bcm-recommended-actions",
    "bedrock",
    "bedrock-agent",
    "bedrock-agent-runtime",
    "bedrock-agentcore",
    "bedrock-agentcore-control",
    "bedrock-data-automation",
    "bedrock-data-automation-runtime",
    "bedrock-runtime",
    "billing",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chatbot",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "chime-sdk-voice",
    "cleanrooms",
    "cleanroomsml",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudfront-keyvaluestore",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudtrail-data",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecatalyst",
    "codecommit",
    "codeconnections",
    "codedeploy",
    "codeguru-reviewer",
    "codeguru-security",
    "codeguruprofiler",
    "codepipeline",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "compute-optimizer-automation",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectcampaignsv2",
    "connectcases",
    "connectparticipant",
    "controlcatalog",
    "controltower",
    "cost-optimization-hub",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "datazone",
    "dax",
    "deadline",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "docdb-elastic",
    "drs",
    "ds",
    "ds-data",
    "dsql",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "eks-auth",
    "elasticache",
    "elasticbeanstalk",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "entityresolution",
    "es",
    "events",
    "evidently",
    "evs",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "freetier",
    "fsx",
    "gamelift",
    "gameliftstreams",
    "geo-maps",
    "geo-places",
    "geo-routes",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector-scan",
    "inspector2",
    "internetmonitor",
    "invoicing",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot-managed-integrations",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleetwise",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivs-realtime",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "kendra-ranking",
    "keyspaces",
    "keyspacesstreams",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesis-video-webrtc-storage",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "launch-wizard",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-linux-subscriptions",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "m2",
    "machinelearning",
    "macie2",
    "mailmanager",
    "managedblockchain",
    "managedblockchain-query",
    "marketplace-agreement",
    "marketplace-catalog",
    "marketplace-deployment",
    "marketplace-entitlement",
    "marketplace-reporting",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediapackagev2",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "medical-imaging",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhuborchestrator",
    "migrationhubstrategy",
    "mpa",
    "mq",
    "mturk",
    "mwaa",
    "mwaa-serverless",
    "neptune",
    "neptune-graph",
    "neptunedata",
    "network-firewall",
    "networkflowmonitor",
    "networkmanager",
    "networkmonitor",
    "notifications",
    "notificationscontacts",
    "nova-act",
    "oam",
    "observabilityadmin",
    "odb",
    "omics",
    "opensearch",
    "opensearchserverless",
    "organizations",
    "osis",
    "outposts",
    "panorama",
    "partnercentral-account",
    "partnercentral-benefits",
    "partnercentral-channel",
    "partnercentral-selling",
    "payment-cryptography",
    "payment-cryptography-data",
    "pca-connector-ad",
    "pca-connector-scep",
    "pcs",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "pipes",
    "polly",
    "pricing",
    "proton",
    "qapps",
    "qbusiness",
    "qconnect",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "repostspace",
    "resiliencehub",
    "resource-explorer-2",
    "resource-groups",
    "resourcegroupstaggingapi",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53globalresolver",
    "route53profiles",
    "route53resolver",
    "rtbfabric",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "s3tables",
    "s3vectors",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-geospatial",
    "sagemaker-metrics",
    "sagemaker-runtime",
    "savingsplans",
    "scheduler",
    "schemas",
    "sdb",
    "secretsmanager",
    "security-ir",
    "securityhub",
    "securitylake",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "signin",
    "simspaceweaver",
    "snow-device-management",
    "snowball",
    "sns",
    "socialmessaging",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-guiconnect",
    "ssm-incidents",
    "ssm-quicksetup",
    "ssm-sap",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "supplychain",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "taxsettings",
    "textract",
    "timestream-influxdb",
    "timestream-query",
    "timestream-write",
    "tnb",
    "transcribe",
    "transfer",
    "translate",
    "trustedadvisor",
    "verifiedpermissions",
    "voice-id",
    "vpc-lattice",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wickr",
    "wisdom",
    "workdocs",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-instances",
    "workspaces-thin-client",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation", "cloudwatch", "dynamodb", "ec2", "glacier", "iam", "s3", "sns", "sqs"
]
PaginatorName = Literal[
    "describe_addon_versions",
    "describe_cluster_versions",
    "list_access_entries",
    "list_access_policies",
    "list_addons",
    "list_associated_access_policies",
    "list_capabilities",
    "list_clusters",
    "list_eks_anywhere_subscriptions",
    "list_fargate_profiles",
    "list_identity_provider_configs",
    "list_insights",
    "list_nodegroups",
    "list_pod_identity_associations",
    "list_updates",
]
WaiterName = Literal[
    "addon_active",
    "addon_deleted",
    "cluster_active",
    "cluster_deleted",
    "fargate_profile_active",
    "fargate_profile_deleted",
    "nodegroup_active",
    "nodegroup_deleted",
]
RegionName = Literal[
    "af-south-1",
    "ap-east-1",
    "ap-east-2",
    "ap-northeast-1",
    "ap-northeast-2",
    "ap-northeast-3",
    "ap-south-1",
    "ap-south-2",
    "ap-southeast-1",
    "ap-southeast-2",
    "ap-southeast-3",
    "ap-southeast-4",
    "ap-southeast-5",
    "ap-southeast-6",
    "ap-southeast-7",
    "ca-central-1",
    "ca-west-1",
    "eu-central-1",
    "eu-central-2",
    "eu-north-1",
    "eu-south-1",
    "eu-south-2",
    "eu-west-1",
    "eu-west-2",
    "eu-west-3",
    "il-central-1",
    "me-central-1",
    "me-south-1",
    "mx-central-1",
    "sa-east-1",
    "us-east-1",
    "us-east-2",
    "us-west-1",
    "us-west-2",
]
